from google.protobuf.json_format import ParseDict
from dig_ass_critic_protos.DigitalAssistantText_pb2_grpc import DigitalAssistantTextStub
from dig_ass_critic_protos.DigitalAssistantText_pb2 import DigitalAssistantTextRequest, DigitalAssistantTextResponse, ChatItem

from abstract_client import AbstractClient

class TextClient(AbstractClient):
    def __init__(self, address) -> None:
        super().__init__(address)
        self._stub = DigitalAssistantTextStub(self._channel)

    def __call__(self, text: str, chat: dict):
        request = DigitalAssistantTextRequest(
            Text=text,
            Chat=ParseDict(chat, ChatItem()),
        )
        response: DigitalAssistantTextResponse = self._stub.GetTextResponse(request)
        return response.Text



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dig_ass_text_protos/DigitalAssistantText.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.dig_ass_text_protos/DigitalAssistantText.proto\x12\x0f\x64ig.ass.text.v1\",\n\x1c\x44igitalAssistantTextResponse\x12\x0c\n\x04Text\x18\x01 \x01(\t\"T\n\x1b\x44igitalAssistantTextRequest\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\'\n\x04\x43hat\x18\x02 \x01(\x0b\x32\x19.dig.ass.text.v1.ChatItem\"|\n\x08\x43hatItem\x12\x37\n\x0cOuterContext\x18\x01 \x01(\x0b\x32!.dig.ass.text.v1.OuterContextItem\x12\x37\n\x0cInnerContext\x18\x02 \x01(\x0b\x32!.dig.ass.text.v1.InnerContextItem\"O\n\x10OuterContextItem\x12\x0b\n\x03Sex\x18\x01 \x01(\x08\x12\x0b\n\x03\x41ge\x18\x02 \x01(\r\x12\x0e\n\x06UserId\x18\x03 \x01(\x03\x12\x11\n\tSessionId\x18\x04 \x01(\r\"B\n\x10InnerContextItem\x12.\n\x08Replicas\x18\x01 \x03(\x0b\x32\x1c.dig.ass.text.v1.ReplicaItem\";\n\x0bReplicaItem\x12\x0c\n\x04\x42ody\x18\x01 \x01(\t\x12\x0c\n\x04Role\x18\x02 \x01(\x08\x12\x10\n\x08\x44\x61teTime\x18\x03 \x01(\t2\x86\x01\n\x14\x44igitalAssistantText\x12n\n\x0fGetTextResponse\x12,.dig.ass.text.v1.DigitalAssistantTextRequest\x1a-.dig.ass.text.v1.DigitalAssistantTextResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dig_ass_text_protos.DigitalAssistantText_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DIGITALASSISTANTTEXTRESPONSE']._serialized_start=67
  _globals['_DIGITALASSISTANTTEXTRESPONSE']._serialized_end=111
  _globals['_DIGITALASSISTANTTEXTREQUEST']._serialized_start=113
  _globals['_DIGITALASSISTANTTEXTREQUEST']._serialized_end=197
  _globals['_CHATITEM']._serialized_start=199
  _globals['_CHATITEM']._serialized_end=323
  _globals['_OUTERCONTEXTITEM']._serialized_start=325
  _globals['_OUTERCONTEXTITEM']._serialized_end=404
  _globals['_INNERCONTEXTITEM']._serialized_start=406
  _globals['_INNERCONTEXTITEM']._serialized_end=472
  _globals['_REPLICAITEM']._serialized_start=474
  _globals['_REPLICAITEM']._serialized_end=533
  _globals['_DIGITALASSISTANTTEXT']._serialized_start=536
  _globals['_DIGITALASSISTANTTEXT']._serialized_end=670
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DigitalAssistantTextResponse(_message.Message):
    __slots__ = ("Text",)
    TEXT_FIELD_NUMBER: _ClassVar[int]
    Text: str
    def __init__(self, Text: _Optional[str] = ...) -> None: ...

class DigitalAssistantTextRequest(_message.Message):
    __slots__ = ("Text", "Chat")
    TEXT_FIELD_NUMBER: _ClassVar[int]
    CHAT_FIELD_NUMBER: _ClassVar[int]
    Text: str
    Chat: ChatItem
    def __init__(self, Text: _Optional[str] = ..., Chat: _Optional[_Union[ChatItem, _Mapping]] = ...) -> None: ...

class ChatItem(_message.Message):
    __slots__ = ("OuterContext", "InnerContext")
    OUTERCONTEXT_FIELD_NUMBER: _ClassVar[int]
    INNERCONTEXT_FIELD_NUMBER: _ClassVar[int]
    OuterContext: OuterContextItem
    InnerContext: InnerContextItem
    def __init__(self, OuterContext: _Optional[_Union[OuterContextItem, _Mapping]] = ..., InnerContext: _Optional[_Union[InnerContextItem, _Mapping]] = ...) -> None: ...

class OuterContextItem(_message.Message):
    __slots__ = ("Sex", "Age", "UserId", "SessionId")
    SEX_FIELD_NUMBER: _ClassVar[int]
    AGE_FIELD_NUMBER: _ClassVar[int]
    USERID_FIELD_NUMBER: _ClassVar[int]
    SESSIONID_FIELD_NUMBER: _ClassVar[int]
    Sex: bool
    Age: int
    UserId: int
    SessionId: int
    def __init__(self, Sex: bool = ..., Age: _Optional[int] = ..., UserId: _Optional[int] = ..., SessionId: _Optional[int] = ...) -> None: ...

class InnerContextItem(_message.Message):
    __slots__ = ("Replicas",)
    REPLICAS_FIELD_NUMBER: _ClassVar[int]
    Replicas: _containers.RepeatedCompositeFieldContainer[ReplicaItem]
    def __init__(self, Replicas: _Optional[_Iterable[_Union[ReplicaItem, _Mapping]]] = ...) -> None: ...

class ReplicaItem(_message.Message):
    __slots__ = ("Body", "Role", "DateTime")
    BODY_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    DATETIME_FIELD_NUMBER: _ClassVar[int]
    Body: str
    Role: bool
    DateTime: str
    def __init__(self, Body: _Optional[str] = ..., Role: bool = ..., DateTime: _Optional[str] = ...) -> None: ...



import io
import re
from setuptools import setup, find_packages

from dig_ass_text_protos import __version__


def read(file_path):
    with io.open(file_path, "r", encoding="utf-8") as f:
        return f.read()


readme = read("README.md")
# вычищаем локальные версии из файла requirements (согласно PEP440)
requirements = "\n".join(
    re.findall(
        r"^([^\s^+]+).*$",
        read("requirements.txt"),
        flags=re.MULTILINE,
    )
)

setup(
    # metadata
    name="dig_ass_text_protos",
    version=__version__,
    author="AGI-MED-TEAM",
    description="Proto files for dig_ass_text_protos",
    long_description=readme,
    # options
    packages=find_packages(),
    install_requires="\n".join([requirements]),
    include_package_data=True,
)
